==> kara-uc-1.1.93.tgz: package/src/kara-uc/components/UCFavorite/All/index.js <==
import React, {Component} from 'react'
import {inject, observer} from "mobx-react"
import css from './index.scss'
import DataUtil from '../../../util/dateTime'
import ColleagueComponent from '../All/colleagueComponent/index'
import NewsComponent from '../All/newsComponent/index'
import FileComponent from '../All/fileComponent/index'
import ImgComponent from '../All/imgComponent/index'
import VideoComponent from '../All/videoComponent/index'
import LinkComponent from '../All/linkComponent/index'
import TextComponent from '../All/textComponent/index'
import {Tost} from "karaui";
import Nothing from "../../nothing/nothing";

@inject('FavoriteStore', 'ConfigStore')
@observer
class KaraAll extends Component {
  constructor(props) {
    super(props)
  }

  onBottom = () => {
    let pn = this.props.FavoriteStore.allList.pageNo + 1
    this.props.ConfigStore.config.httpAgent.post('/search/favor/favorAll', {
      keywords: this.props.keywords,
      isShowRich: 'true',
      pageInfo: {
        pageSize: this.props.FavoriteStore.allList.pageSiz,
        pageNo: pn
      }
    }).then(
      res => {
        if (res && res.resultCode && res.resultCode === '000000') {
          this.props.FavoriteStore.getAllList(res, pn)
        }
        else {
          Tost({type: 'error', msg: '列表信息加载失败', time: 4})
        }
      }
    )
  }

  componentDidMount() {
    this.props.ConfigStore.config.httpAgent.post('/search/favor/favorAll', {
      keywords: this.props.keywords,
      isShowRich: 'true',
      pageInfo: {
        pageSize: this.props.FavoriteStore.allList.pageSiz,
        pageNo: this.props.FavoriteStore.allList.pageNo
      }
    }).then(
      res => {
        if (res && res.resultCode && res.resultCode === '000000') {
          this.props.FavoriteStore.getAllList(res, this.props.FavoriteStore.allList.pageNo)
        }
        else {
          Tost({type: 'error', msg: '列表信息加载失败', time: 4})
        }
      }
    )
  }

  componentWillReceiveProps(nextProps) {
    if (this.props.keywords !== nextProps.keywords) {
      this.props.ConfigStore.config.httpAgent.post('/search/favor/favorAll', {
        keywords: nextProps.keywords,
        isShowRich: 'true',
        pageInfo: {
          pageSize: this.props.FavoriteStore.allList.pageSiz,
          pageNo: 1
        }
      }).then(
        res => {
          if (res && res.resultCode && res.resultCode === '000000') {
            this.props.FavoriteStore.getAllList(res, this.props.FavoriteStore.allList.pageNo)
          }
          else {
            Tost({type: 'error', msg: '列表信息加载失败', time: 4})
          }
        }
      )
    }
  }

  getDomByItemType = (item) => {
    const {lang, ConfigStore} = this.props
    const {karaui, httpAgent} = ConfigStore.config
    if (item.favoriteType === 'quan_topic') {
      return <ColleagueComponent
        key={item.id}
        fileAttr={item}
        fromPage='all'
        lang={lang}
        httpAgent={httpAgent}
        karaui={karaui}
        cancelImFavorite={this.props.FavoriteStore.cancelImFavorite}
        cancelCmsFavorite={this.props.FavoriteStore.cancelCmsFavorite}/>
    } else if (item.favoriteType === 'cms') {
      return <NewsComponent
        key={`${item.favoriteType || 'cms'}${item.ts || item.sesFavoriteCmsInfo&&item.sesFavoriteCmsInfo.articleId}`}
        fileAttr={item}
        fromPage='all'
        lang={lang}
        httpAgent={httpAgent}
        karaui={karaui}
        cancelImFavorite={this.props.FavoriteStore.cancelImFavorite}
        cancelCmsFavorite={this.props.FavoriteStore.cancelCmsFavorite}/>
    } else if (item.favoriteType === 'im') {
      if (item.type === 'EVENT_MESSAGE') {
        if (item.fileType === 'rar' || item.fileType === 'zip' ||
          item.fileType === 'psd' || item.fileType === 'pdf' ||
          item.fileType === 'rp' || item.fileType === 'txt' ||
          item.fileType === 'exe' || item.fileType === 'tmp' ||
          item.fileType === 'ppt' || item.fileType === 'pptx' ||
          item.fileType === 'xls' || item.fileType === 'xlsx' ||
          item.fileType === 'doc' || item.fileType === 'docx' || item.fileType === 'rp') {
          return <FileComponent
            key={item.id}
            fileAttr={item}
            fromPage='all'
            downLoadFile={this.props.FavoriteStore.downLoadFile}
            contentRef={this.props.contentRef}
            lang={lang}
            httpAgent={httpAgent}
            karaui={karaui}
            cancelImFavorite={this.props.FavoriteStore.cancelImFavorite}
            cancelCmsFavorite={this.props.FavoriteStore.cancelCmsFavorite}/>
        } else if (this.props.FavoriteStore.imgType.includes(item.fileType)) {
          return <ImgComponent
            key={item.id}
            fileAttr={item}
            fromPage='all'
            contentRef={this.props.contentRef}
            imgViewList={this.props.FavoriteStore.imgViewList}
            lang={lang}
            httpAgent={httpAgent}
            karaui={karaui}
            cancelImFavorite={this.props.FavoriteStore.cancelImFavorite}
            cancelCmsFavorite={this.props.FavoriteStore.cancelCmsFavorite}/>
        } else if (item.videoLen !== 0) {
          return <VideoComponent
            key={item.id}
            fileAttr={item}
            fromPage='all'
            contentRef={this.props.contentRef}
            imgViewList={this.props.FavoriteStore.imgViewList}
            lang={lang}
            httpAgent={httpAgent}
            karaui={karaui}
            cancelImFavorite={this.props.FavoriteStore.cancelImFavorite}
            cancelCmsFavorite={this.props.FavoriteStore.cancelCmsFavorite}/>
        }
      } else if (item.type === 'PLAIN_MESSAGE') {
        return <TextComponent
          key={item.id}
          fileAttr={item}
          fromPage='all'
          lang={lang}
          httpAgent={httpAgent}
          karaui={karaui}
          cancelImFavorite={this.props.FavoriteStore.cancelImFavorite}
          cancelCmsFavorite={this.props.FavoriteStore.cancelCmsFavorite}/>
      } else if (item.type === 'RICH_MESSAGE') {
        return <LinkComponent
          key={item.id}
          fileAttr={item}
          fromPage='all'
          lang={lang}
          httpAgent={httpAgent}
          karaui={karaui}
          cancelImFavorite={this.props.FavoriteStore.cancelImFavorite}
          cancelCmsFavorite={this.props.FavoriteStore.cancelCmsFavorite}/>
      }
    }
  }

  render() {
    const {ConfigStore, FavoriteStore,lang} = this.props
    const {karaui: {Scroll}} = ConfigStore.config
    const {allList} = FavoriteStore
    return (
      <div className={css.KaraAll}>
        <Scroll onScrollBottom={this.onBottom}>
          {allList.result.length>0 ? allList.result.map((item) => {
            return this.getDomByItemType(item)
          }) : <Nothing lang={lang}/>}
        </Scroll>
      </div>
    )
  }
}

export default KaraAll

==> kara-uc-1.2.28.tgz: package/src/kara-uc/components/UCFavorite/All/index.js <==
import React, {Component} from 'react'
import {inject, observer} from "mobx-react"
import css from './index.scss'
import DataUtil from '../../../util/dateTime'
import ColleagueComponent from '../All/colleagueComponent/index'
import NewsComponent from '../All/newsComponent/index'
import FileComponent from '../All/fileComponent/index'
import ImgComponent from '../All/imgComponent/index'
import VideoComponent from '../All/videoComponent/index'
import LinkComponent from '../All/linkComponent/index'
import TextComponent from '../All/textComponent/index'
import {Tost} from "karaui";
import Nothing from "../../nothing/nothing";

@inject('FavoriteStore', 'ConfigStore')
@observer
class KaraAll extends Component {
  constructor(props) {
    super(props)
  }

  onBottom = () => {
    let pn = this.props.FavoriteStore.allList.pageNo + 1
    this.props.ConfigStore.config.httpAgent.post('/search/favor/favorAll', {
      keywords: this.props.keywords,
      isShowRich: 'true',
      pageInfo: {
        pageSize: this.props.FavoriteStore.allList.pageSiz,
        pageNo: pn
      }
    }).then(
      res => {
        if (res && res.resultCode && res.resultCode === '000000') {
          this.props.FavoriteStore.getAllList(res, pn)
        }
        else {
          Tost({type: 'error', msg: '列表信息加载失败', time: 4})
        }
      }
    )
  }

  componentDidMount() {
    this.props.ConfigStore.config.httpAgent.post('/search/favor/favorAll', {
      keywords: this.props.keywords,
      isShowRich: 'true',
      pageInfo: {
        pageSize: this.props.FavoriteStore.allList.pageSiz,
        pageNo: this.props.FavoriteStore.allList.pageNo
      }
    }).then(
      res => {
        if (res && res.resultCode && res.resultCode === '000000') {
          this.props.FavoriteStore.getAllList(res, this.props.FavoriteStore.allList.pageNo)
        }
        else {
          Tost({type: 'error', msg: '列表信息加载失败', time: 4})
        }
      }
    )
  }

  componentWillReceiveProps(nextProps) {
    if (this.props.keywords !== nextProps.keywords) {
      this.props.ConfigStore.config.httpAgent.post('/search/favor/favorAll', {
        keywords: nextProps.keywords,
        isShowRich: 'true',
        pageInfo: {
          pageSize: this.props.FavoriteStore.allList.pageSiz,
          pageNo: 1
        }
      }).then(
        res => {
          if (res && res.resultCode && res.resultCode === '000000') {
            this.props.FavoriteStore.getAllList(res, this.props.FavoriteStore.allList.pageNo)
          }
          else {
            Tost({type: 'error', msg: '列表信息加载失败', time: 4})
          }
        }
      )
    }
  }

  getDomByItemType = (item,k) => {
    const {lang, ConfigStore} = this.props
    const {karaui, httpAgent} = ConfigStore.config
    if (item.favoriteType === 'quan_topic') {
      return <ColleagueComponent
        key={k}
        fileAttr={item}
        fromPage='all'
        lang={lang}
        httpAgent={httpAgent}
        karaui={karaui}
        cancelImFavorite={this.props.FavoriteStore.cancelImFavorite}
        cancelCmsFavorite={this.props.FavoriteStore.cancelCmsFavorite}/>
    } else if (item.favoriteType === 'cms') {
      return <NewsComponent
        key={`${item.favoriteType || 'cms'}${item.ts || item.sesFavoriteCmsInfo&&item.sesFavoriteCmsInfo.articleId}`}
        fileAttr={item}
        fromPage='all'
        lang={lang}
        httpAgent={httpAgent}
        karaui={karaui}
        cancelImFavorite={this.props.FavoriteStore.cancelImFavorite}
        cancelCmsFavorite={this.props.FavoriteStore.cancelCmsFavorite}/>
    } else if (item.favoriteType === 'im') {
      if (item.type === 'EVENT_MESSAGE') {
        if (item.fileType === 'rar' || item.fileType === 'zip' ||
          item.fileType === 'psd' || item.fileType === 'pdf' ||
          item.fileType === 'rp' || item.fileType === 'txt' ||
          item.fileType === 'exe' || item.fileType === 'tmp' ||
          item.fileType === 'ppt' || item.fileType === 'pptx' ||
          item.fileType === 'xls' || item.fileType === 'xlsx' ||
          item.fileType === 'doc' || item.fileType === 'docx' || item.fileType === 'rp') {
          return <FileComponent
            key={item.id}
            fileAttr={item}
            fromPage='all'
            downLoadFile={this.props.FavoriteStore.downLoadFile}
            contentRef={this.props.contentRef}
            lang={lang}
            httpAgent={httpAgent}
            karaui={karaui}
            cancelImFavorite={this.props.FavoriteStore.cancelImFavorite}
            cancelCmsFavorite={this.props.FavoriteStore.cancelCmsFavorite}/>
        } else if (this.props.FavoriteStore.imgType.includes(item.fileType)) {
          return <ImgComponent
            key={item.id}
            fileAttr={item}
            fromPage='all'
            contentRef={this.props.contentRef}
            imgViewList={this.props.FavoriteStore.imgViewList}
            lang={lang}
            httpAgent={httpAgent}
            karaui={karaui}
            cancelImFavorite={this.props.FavoriteStore.cancelImFavorite}
            cancelCmsFavorite={this.props.FavoriteStore.cancelCmsFavorite}/>
        } else if (item.videoLen !== 0) {
          return <VideoComponent
            key={item.id}
            fileAttr={item}
            fromPage='all'
            contentRef={this.props.contentRef}
            imgViewList={this.props.FavoriteStore.imgViewList}
            lang={lang}
            httpAgent={httpAgent}
            karaui={karaui}
            cancelImFavorite={this.props.FavoriteStore.cancelImFavorite}
            cancelCmsFavorite={this.props.FavoriteStore.cancelCmsFavorite}/>
        }
      } else if (item.type === 'PLAIN_MESSAGE') {
        return <TextComponent
          key={item.id}
          fileAttr={item}
          fromPage='all'
          lang={lang}
          httpAgent={httpAgent}
          karaui={karaui}
          cancelImFavorite={this.props.FavoriteStore.cancelImFavorite}
          cancelCmsFavorite={this.props.FavoriteStore.cancelCmsFavorite}/>
      } else if (item.type === 'RICH_MESSAGE') {
        return <LinkComponent
          key={item.id}
          fileAttr={item}
          fromPage='all'
          lang={lang}
          httpAgent={httpAgent}
          karaui={karaui}
          cancelImFavorite={this.props.FavoriteStore.cancelImFavorite}
          cancelCmsFavorite={this.props.FavoriteStore.cancelCmsFavorite}/>
      }
    }
  }

  render() {
    const {ConfigStore, FavoriteStore,lang} = this.props
    const {karaui: {Scroll}} = ConfigStore.config
    const {allList} = FavoriteStore
    return (
      <div className={css.KaraAll}>
        <Scroll onScrollBottom={this.onBottom}>
          {allList.result.length>0 ? allList.result.map((item,k) => {
            return this.getDomByItemType(item,k)
          }) : <Nothing lang={lang}/>}
        </Scroll>
      </div>
    )
  }
}

export default KaraAll
